[![Documentation Status](https://readthedocs.org/projects/pyco2stats/badge/?version=latest)](https://pyco2stats.readthedocs.io/en/latest/)

# pyco2stats

A Python package to do statistical analyses for CO2 degassing processes.

## Features

 - Gaussian mixtures: module that implements the possibility to perform gaussian mixtures models.
 - Sinclair: module for the implementation of the Sinclair method.
 - Stats: various statistical methods.
 - Visualize: visualization module.

## Installation

pyco2stats can be installed using pip:

pip install pyco2stats
